==> kubernetes-model-1.0.30-sources.jar: io/fabric8/kubernetes/api/model/GitRepoVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class GitRepoVolumeSourceBuilder extends GitRepoVolumeSourceFluentImpl<GitRepoVolumeSourceBuilder> implements VisitableBuilder<GitRepoVolumeSource,GitRepoVolumeSourceBuilder>{

     GitRepoVolumeSourceFluent<?> fluent;
public GitRepoVolumeSourceBuilder(){
    this(new GitRepoVolumeSource());
}
public GitRepoVolumeSourceBuilder( GitRepoVolumeSourceFluent<?> fluent ){
    this(fluent, new GitRepoVolumeSource());
}
public GitRepoVolumeSourceBuilder( GitRepoVolumeSourceFluent<?> fluent , GitRepoVolumeSource instance ){
    this.fluent = fluent; fluent.withRepository(instance.getRepository()); fluent.withRevision(instance.getRevision()); 
}
public GitRepoVolumeSourceBuilder( GitRepoVolumeSource instance ){
    this.fluent = this; this.withRepository(instance.getRepository()); this.withRevision(instance.getRevision()); 
}

public EditableGitRepoVolumeSource build(){
    EditableGitRepoVolumeSource buildable = new EditableGitRepoVolumeSource(fluent.getRepository(),fluent.getRevision());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
GitRepoVolumeSourceBuilder that = (GitRepoVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.42-sources.jar: io/fabric8/kubernetes/api/model/GitRepoVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class GitRepoVolumeSourceBuilder extends GitRepoVolumeSourceFluentImpl<GitRepoVolumeSourceBuilder> implements VisitableBuilder<GitRepoVolumeSource,GitRepoVolumeSourceBuilder>{

     GitRepoVolumeSourceFluent<?> fluent;
public GitRepoVolumeSourceBuilder(){
    this(new GitRepoVolumeSource());
}
public GitRepoVolumeSourceBuilder( GitRepoVolumeSourceFluent<?> fluent ){
    this(fluent, new GitRepoVolumeSource());
}
public GitRepoVolumeSourceBuilder( GitRepoVolumeSourceFluent<?> fluent , GitRepoVolumeSource instance ){
    this.fluent = fluent; fluent.withDirectory(instance.getDirectory()); fluent.withRepository(instance.getRepository()); fluent.withRevision(instance.getRevision()); 
}
public GitRepoVolumeSourceBuilder( GitRepoVolumeSource instance ){
    this.fluent = this; this.withDirectory(instance.getDirectory()); this.withRepository(instance.getRepository()); this.withRevision(instance.getRevision()); 
}

public EditableGitRepoVolumeSource build(){
    EditableGitRepoVolumeSource buildable = new EditableGitRepoVolumeSource(fluent.getDirectory(),fluent.getRepository(),fluent.getRevision());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
GitRepoVolumeSourceBuilder that = (GitRepoVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
